@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright 2019-2024 Jean-Baptiste Delisle
 # Licensed under the EUPL-1.2 or later
 
@@ -677,6 +675,8 @@ class Matern32Kernel(Kernel):
     self._sig = sig
     self._rho = rho
     self._r = 2
+    self._a = self._sig**2
+    self._la = np.sqrt(3) / self._rho
     self._param = ['sig', 'rho']
 
   def _link(self, cov, offset):
@@ -685,8 +685,6 @@ class Matern32Kernel(Kernel):
     self._dt0 = self._cov.t - self._t0
 
   def _compute(self):
-    self._a = self._sig**2
-    self._la = np.sqrt(3) / self._rho
     self._la2 = self._la**2
     self._x = self._la * self._dt0
     self._1mx = 1 - self._x
@@ -704,6 +702,8 @@ class Matern32Kernel(Kernel):
       self._sig = sig
     if rho is not None:
       self._rho = rho
+    self._a = self._sig**2
+    self._la = np.sqrt(3) / self._rho
 
   def _grad_param(self, grad_dU=None, grad_dV=None):
     grad = {}
@@ -842,6 +842,8 @@ class Matern52Kernel(Kernel):
     self._sig = sig
     self._rho = rho
     self._r = 3
+    self._a = self._sig**2
+    self._la = np.sqrt(5) / self._rho
     self._param = ['sig', 'rho']
 
   def _link(self, cov, offset):
@@ -850,8 +852,6 @@ class Matern52Kernel(Kernel):
     self._dt0 = self._cov.t - self._t0
 
   def _compute(self):
-    self._a = self._sig**2
-    self._la = np.sqrt(5) / self._rho
     self._la2 = self._la**2
     self._x = self._la * self._dt0
     self._x2_3 = self._x * self._x / 3
@@ -872,6 +872,8 @@ class Matern52Kernel(Kernel):
       self._sig = sig
     if rho is not None:
       self._rho = rho
+    self._a = self._sig**2
+    self._la = np.sqrt(5) / self._rho
 
   def _grad_param(self, grad_dU=None, grad_dV=None):
     grad = {}
@@ -1020,6 +1022,12 @@ class Matern52Kernel(Kernel):
 class SumKernel(Kernel):
   r"""
   Generic class for the sum of several kernel terms.
+
+  The :class:`SimpleSumKernel` class should be used instead of this unless
+  specific parameters mapping are required.
+  This class should not be used as is, but should be inherited from
+  and the :func:`_kernel_param` and :func:`_kernel_param_back` methods
+  should be defined to deal with the parameters mapping.
   """
 
   def __init__(self, *args):
@@ -1098,7 +1106,17 @@ class SumKernel(Kernel):
 
 
 class SimpleSumKernel(SumKernel):
-  r""" """
+  r"""
+  Sum of several kernel terms.
+
+  The :class:`SumKernel` class can be used for more advanced parameters mapping.
+
+  Parameters
+  ----------
+  **kwargs:
+    Kernels to be summed, indexed by their names.
+    The names used here will then be prepended to all corresponding parameters names.
+  """
 
   def __init__(self, **kwargs):
     self._kerneldic = kwargs
@@ -1168,6 +1186,12 @@ class _FakeCov:
 class ProductKernel(Kernel):
   r"""
   Generic class for the product of two kernel terms.
+
+  The :class:`SimpleProductKernel` class should be used instead of this unless
+  specific parameters mapping are required.
+  This class should not be used as is, but should be inherited from
+  and the :func:`_kernel_param` and :func:`_kernel_param_back` methods
+  should be defined to deal with the parameters mapping.
   """
 
   def __init__(self, kernel1, kernel2):
@@ -1565,7 +1589,17 @@ class ProductKernel(Kernel):
 
 
 class SimpleProductKernel(ProductKernel):
-  r""" """
+  r"""
+  Product of two kernel terms.
+
+  The :class:`ProductKernel` class can be used for more advanced parameters mapping.
+
+  Parameters
+  ----------
+  **kwargs:
+    Kernels to be multiplied together, indexed by their names.
+    The names used here will then be prepended to all corresponding parameters names.
+  """
 
   def __init__(self, **kwargs):
     assert len(kwargs) == 2
@@ -1608,6 +1642,23 @@ class SimpleProductKernel(ProductKernel):
 
 
 class TransformKernel(Kernel):
+  r"""
+  Wrapper to apply a change of parameters to any kernel.
+
+  Parameters
+  ----------
+    inner_kernel: Kernel
+      Kernel to be used internally.
+    translate_param: function
+      Function to compute the inner kernel parameters as a function
+      of the new parameters which will be presented to the user.
+    translate_param_back: function (optional)
+      Back propagation of the gradient for translate_param.
+      This should be provided if the gradient with respect to parameters is needed.
+    **kwargs:
+      Parameters (new) to be provided to initialize the kernel.
+  """
+
   def __init__(
     self, inner_kernel, translate_param, translate_param_back=None, **kwargs
   ):
@@ -1742,7 +1793,7 @@ class USHOKernel(QuasiperiodicKernel):
     grad['Q'] = (
       -np.pi / (self._P0 * self._Q**2) * (gradQP['la'] + gradQP['nu'] * self._sqQ)
     )
-    if 4 * self._Q**2 - 1 > self._eps:
+    if self._eps < 4 * self._Q**2 - 1:
       grad['Q'] += (
         4
         * self._Q
@@ -1826,7 +1877,7 @@ class OSHOKernel(SumKernel):
       / (self._P0 * self._Q**2)
       * (gradExp1['la'] * (1 - self._sqQ) + gradExp2['la'] * (1 + self._sqQ))
     )
-    if 1 - 4 * self._Q**2 > self._eps:
+    if self._eps < 1 - 4 * self._Q**2:
       grad['Q'] -= (
         4
         * self._Q
@@ -2629,8 +2680,8 @@ class MultiFourierKernel(Kernel):
 
   Parameters
   ----------
-  nu : float
-    Fundamental angular frequency.
+  P : float
+    Fundamental period (related to the fundamental impulsion :math:`\nu=\frac{2\pi}{P}`).
   alpha, beta: (nharm + 1, m, r) ndarrays
     Fourier coefficients. beta[0] should be filled with zeros.
   series_index : list of ndarrays
@@ -2850,18 +2901,14 @@ class MultiFourierKernel(Kernel):
     ----------
     alpha, beta : (nharm + 1, r) ndarray
       Fourier coefficients for the conditional computation.
-      This is only used if series_id is None.
     series_id : int
       Use the coefficents corresponding to a given time series.
+      This is only used if alpha, beta are None.
     """
 
-    self._cond_series_id = series_id
-    if series_id is None:
-      self._cond_alpha = alpha
-      self._cond_beta = beta
-    else:
-      self._cond_alpha = None
-      self._cond_beta = None
+    self._cond_alpha = alpha
+    self._cond_beta = beta
+    self._cond_series_id = series_id if alpha is None else None
 
   def _compute_t2(
     self, t2, dt2, U2, V2, phi2, ref2left, dt2left, dt2right, phi2left, phi2right
